selectionDet <- function( init.A=0.05, s=0.01, h=0.5, stoptime=2000 ){
  
   deq <- function( t, y, parms ) {
      s <- parms["s"]
      h <- parms["h"]
      w.bar <- y^2 + 2*(1-s*h)*y*(1-y) + (1-s)*(1-y)^2
      y.prime <- s*y*(1-y)*(1-h+y*(2*h-1)) / w.bar
   
      return( list( y.prime, c( y.prime=y.prime, w.bar=w.bar ) ) )
   }

   # check init.A 
   if ( init.A < 0 || init.A > 1 )
      stop( "init.A must be between 0 and 1" )

   # check s
   if ( s < 0 || s > 1 )
      stop( "s must be between 0 and 1" )

   # check stoptime
   if ( stoptime <= 0 )
      stop( "stoptime must be greater than 0" )

   res <- lsoda( init.A, 1:stoptime, deq, parms=c("s"=s, "h"=h))

   res <- as.data.frame( res )
   colnames( res ) <- c( "time", "freq.A", "freq.A.prime", "w.bar" )
   res$freq.a <- 1 - res$freq.A
   res$fixed <- ifelse( res$freq.A == 1 || res$freq.A == 0, TRUE, FALSE )

   my.res <- list( "freq.A"=matrix( res$freq.A, ncol=1 ),
                   "freq.a"=matrix( res$freq.a, ncol=1 ),
                   "freq.A.prime"=res$freq.A.prime,
                   "w.bar"=matrix( res$w.bar, ncol=1 ),
                   "fixed"=matrix( res$fixed, ncol=1 ) ) 

   class( my.res ) <- c( "selectionDet", "selection" )

   return( my.res )
}
   

plot.selection <- function( x, what=c( "freq.A", "w.bar" ),
                            col=vector(), xlim=NULL, ylim=c(0,1),
                            xlab="time", ylab="freq",
                            legend.pos="bottomright", ... )
{
   if ( ! inherits( x, "selectionDet" ) && "freq.A.prime" %in% what ) 
      stop( "freq.A.prime is only allowed with selectionDet objects" )

   stoptime <- nrow( x$freq.A ) - 1

   legend <- vector()
   legend.col <- vector()
   
   col["freq.A"] <- ifelse( is.na( col["freq.A"] ), "red",   col["freq.A"] )
   col["freq.a"] <- ifelse( is.na( col["freq.a"] ), "green", col["freq.a"] )
   col["freq.A.prime"] <- ifelse( is.na( col["freq.A.prime"] ), 
                                  "black", col["freq.A.prime"] )
   col["w.bar"]  <- ifelse( is.na( col["w.bar"] ),  "violet",col["w.bar"] )
   col["fixed"]  <- ifelse( is.na( col["fixed"] ),  "blue",  col["fixed"] )

   if ( is.null( xlim ) ) {
      xlim <- c( 0, stoptime )
   }

   plot( 0, 0, xlim=xlim, ylim=ylim, type="n", xlab=xlab, ylab=ylab )

   if ( "freq.A" %in% what ) {
      lines( 0:stoptime, apply( x$freq.A, 1, mean ), col=col["freq.A"] )
      legend <- c( legend, "freq.A" )
      legend.col <- c( legend.col, col["freq.A"] )
   }

   if ( "freq.a" %in% what ) {
      lines( 0:stoptime, apply( x$freq.a, 1, mean ), col=col["freq.a"] )
      legend <- c( legend, "freq.a" )
      legend.col <- c( legend.col, col["freq.a"] )
   }

   if ( "freq.A.prime" %in% what ) {
      lines( 0:stoptime, x$freq.A.prime, col=col["freq.A.prime"] )
      legend <- c( legend, "freq.A.prime" )
      legend.col <- c( legend.col, col["freq.A.prime"] )
   }

   if ( "w.bar" %in% what ) {
      lines( 0:stoptime, apply( x$w.bar, 1, mean ), col=col["w.bar"] )
      legend <- c( legend, "w.bar" )
      legend.col <- c( legend.col, col["w.bar"] )
   }

   if ( "fixed" %in% what ) {
      lines( 0:stoptime, apply( x$fixed, 1, mean ), col=col["fixed"] )
      legend <- c( legend, "fixed" )
      legend.col <- c( legend.col, col["fixed"] )
   }

   legend( legend.pos, legend=legend,
           col=legend.col, lty=1, bg="white" )
}
