seqEvoMullersRatchet<-function(N=10, s=0.03, u=0.1, stoptime=20, wait=0, seed=0, seq=TRUE, sfs=FALSE) {
  if(seed) set.seed(seed)

  # N>1 necessary
  if(N<2) {
    print("error: N>1 necessary")
  }

  # s<1 necessary
  if(s>=1) {
    print("error: s<1 necessary")
  }

  # either seq or sfs must be TRUE
  if(seq==FALSE && sfs ==FALSE) {
    print("no output produced")
  }
  
  if(seq==TRUE && sfs==TRUE)
    layout(matrix(c(1,2), ncol=2, nrow=1))
  else 
    layout(matrix(c(1), ncol=1, nrow=1))

  # wait<0 means: ask for input after a plot
  if(wait<0) {
    par(ask=T)
  } else {
    par(ask=FALSE)
  }

  # make starting configuration
  A<-createNeutralA(N,0,u)

  # plot starting configuration
  if(seq) {
    plot(c(0,1), c(1,N), type='n', axes=FALSE, xlab="", ylab="")
    plotA(A)
  }

  # classes 
  class<-1:N
  for(i in 1:N)
    class[i]<-sum(A[[1]][i,])

  t<-0
  while(t<stoptime) {
    mut<-rpois(N, u)
    for(i in 1:N) {
      A<-mutation(A, i, runif(mut[i]))
    }    
    class<-class+mut

    anc<-sort(sample(1:N,N, replace=TRUE, prob=(1-s)^class))

    B<-A[[1]]
    for(i in 1:N) {
      A[[1]][i,]<-B[anc[i],]
    }    

    i<-1
    while(i < length(A[[1]][1,])) {
      if(length(A[[1]][1,])>2 && sum(A[[1]][,i])==0) {
        if(i==1) {
          A[[2]]<-A[[2]][2:length(A[[1]][1,])]
          A[[1]]<-A[[1]][1:N, 2:length(A[[1]][1,])]
        } else if(i<length(A[[1]][1,])) {
          A[[2]]<-c(A[[2]][1:(i-1)], A[[2]][(i+1):length(A[[1]][1,])])
          A[[1]]<-cbind(A[[1]][1:N, 1:(i-1)], A[[1]][1:N, (i+1):length(A[[1]][1,])])
        } else if(i==length(A[[1]][1,])) {
          A[[2]]<-A[[2]][1:(length(A[[1]][1,])-1)]
          A[[1]]<-A[[1]][1:N, 1:(length(A[[1]][1,])-1)]
        } 
      } else {
        i<-i+1
      }
    }

    for(i in 1:N)
      class[i]<-sum(A[[1]][i,])

    if(wait>0) Sys.sleep(wait)

    if(seq) {
      plot(c(0,1), c(1,N), type='n', axes=FALSE, xlab="", ylab="")
      plotA(A)
    }
    if(sfs) {
      plotSFS(A)
    }
    t<-t+1
  }
  minN<-sum(A[[1]][1,])
  for(i in 2:N) {
    minN<-min(sum(A[[1]][i,]),minN)
  }

  print("Minimal number of mutations:")
  minN
}
