seqEvoNeutral<-function(N=10, r=0, u=0.1, stoptime=20, wait=0, showFixed=TRUE, seq=TRUE, sfs=FALSE, seed=0) {
  if(seed) set.seed(seed)

  # N>1 necessary
  if(N<2) {
    print("error: N>1 necessary")
  }

  # either seq or sfs must be TRUE
  if(seq==FALSE && sfs ==FALSE) {
    print("no output produced")
  }
  
  if(seq==TRUE && sfs==TRUE)
    layout(matrix(c(1,2), ncol=2, nrow=1))
  else 
    layout(matrix(c(1), ncol=1, nrow=1))

  # wait<0 mease: ask for input after a plot
  if(wait<0) {
    par(ask=T)
  } else {
    par(ask=FALSE)
  }

  # make starting configuration
  A<-createNeutralA(N,0,u)

  # plot starting configuration
  if(seq) {
    plot(c(0,1), c(1,N), type='n', axes=FALSE, xlab="", ylab="")
    plotA(A)
  }

  if(sfs) {
    plotSFS(A)
  }

  t<-0

  while(t<stoptime) {
    p<-runif(1)
    if(p < 2*r*N/(2*(r+u)*N+N-1)) {
      # recombination
      i<-1+as.integer(N*runif(1))
      j<-1+as.integer(N*runif(1))
      brea<-runif(1)
      A<-recombination(A, i, j, brea)
    } else if(p < 2*(r+u)*N/(2*(r+u)*N+N-1)) {
      # mutation
      i<-1+as.integer(N*runif(1))
      site<-runif(1)
      A<-mutation(A, i, site)
    } else {
      k<-1+as.integer(N*runif(1))
      l<-1+as.integer(N*runif(1))
      A<-resampling(A, k, l)
      if(wait>0) Sys.sleep(wait)

      if(showFixed==FALSE) A<-deleteFixed(A)
      if(seq) {
        plot(c(0,1), c(1,N), type='n', axes=FALSE, xlab="", ylab="")
        plotA(A)
      }
      if(sfs) {
        plotSFS(A)
      }
      t<-t+1
    }
  }
}

