wf.freq <- function( N=500, init.A=0.001, s=0, h=0.5, uA2a=0,
                         ua2A=0, stoptime=500, batch=1 ) {
   eps <- 1e-8

   # check N
   if ( N <= 0 )
      stop( "N must be greater than 0" )

   # check init.A
   if ( init.A < 0 || init.A > 1 )
      stop( "init.A must be between 0 and 1" )

   # check s
   if ( s < 0 || s > 1 )
      stop( "s must be between 0 and 1" )

   # check h
   if ( s > 0 && h > 1/s )
      stop( paste( "s must be lower than 1/s (", 1/s, ")" ) )
   
   # check stoptime
   if ( stoptime <= 0 )
      stop( "stoptime must be greater than 0" )

   # check batch
   if ( batch <= 0 )
      stop( "batch must be greater than 0" )

   
   nn       <- 2*N
   m.freq.A <- vector()
   m.freq.a <- vector()
   m.w.bar  <- vector()
   m.fixed  <- vector()

   # nur zur Beschleunigung
   uA2A <- 1-uA2a
   tmp1 <- 1-s*h
   tmp2 <- 1-s

   first.A.prime <- ( 1-uA2a ) * init.A + ua2A * ( 1-init.A )
   first.a.prime <- 1-first.A.prime

   first.w.bar <- first.A.prime^2 + 2*( 1-s*h )*first.A.prime*first.a.prime + (1-s)*first.a.prime^2

   first.A.tilde <- ( first.A.prime^2 + ( 1-s*h )*first.A.prime*first.a.prime ) / first.w.bar
   
   for ( run in 1:batch ) {
      freq.A <- init.A

      A.prime <- first.A.prime
      a.prime <- first.a.prime
      w.bar <- first.w.bar
      A.tilde  <- first.A.tilde

      for ( i in 2:(stoptime+1) ) {
         freq.A[i] <- rbinom( 1, nn, A.tilde) / nn

         A.prime <- uA2A * freq.A[i] + ua2A * ( 1-freq.A[i] )
         a.prime <- 1-A.prime

         w.bar <- c( w.bar, A.prime^2 + 2*tmp1*A.prime*a.prime + tmp2*a.prime^2 )

         A.tilde <- ( A.prime^2 + tmp1*A.prime*a.prime ) / w.bar[i]
      }

      fixed    <- ifelse( freq.A == 0 | freq.A == 1, TRUE, FALSE )
     
      m.freq.A <- cbind( m.freq.A, freq.A )
      m.w.bar  <- cbind( m.w.bar, w.bar )
      m.fixed  <- cbind( m.fixed, fixed )
   }

   m.freq.a <- 1-m.freq.A

   ret <- list( "freq.A"=m.freq.A, "freq.a"=m.freq.a, "w.bar" = m.w.bar,
                "fixed"=m.fixed )
   class( ret ) <- c( "selectionWF", "selection" )
   
   return( ret )
}
