wf.model<-function(N=10, mark=NULL, T=13, pdf=FALSE, time=TRUE, markMRCA=FALSE, seed=0, tangled=TRUE, untangled=TRUE, col="green", cex=2) {
#time      # TRUE if "generations" should be plotted
#markMRCA  # TRUE if the MRCA should be marked
#seed   # if seed == 0 the seed is taken by R

# sets a seed for the random number generator
if(seed) set.seed(seed)

filename1<-"wfSimul"
if(pdf) pdf(file = paste(filename1, "%01d", ".pdf", sep=""), width=N, height=T+1, family="Times", onefile=FALSE)

anc<-matrix(0, nrow=T, ncol=N)
if(T>1) {
  for(i in 2:T)
    anc[i,]<-as.integer(1+N*runif(N))
}

anc2<-anc
ix<-1:N
for(i in 2:(T)) {
  for(j in 1:(N-1)) {
    for(k in (j+1):N) {
      if(anc2[i,j]>anc2[i,k]) { # swap j and k in generation i
        if(i==T) {
          cc<-ix[j]
          ix[j]<-ix[k]
          ix[k]<-cc
        }
        for(l in 1:N) {
          if(i<T && anc2[i+1,l]==j) {
            anc2[i+1,l]=k
          } else if(i<T && anc2[i+1,l]==k) {
            anc2[i+1,l]=j
          }
        }
        cc=anc2[i,j]
        anc2[i,j]=anc2[i,k]
        anc2[i,k]=cc
      }
    }
  }
}

if(tangled==TRUE && untangled==TRUE)
  layout(matrix(c(1,2), ncol=2, nrow=1))
else 
  layout(matrix(c(1), ncol=1, nrow=1))


# Tangled version

if(tangled==TRUE){
  plot(x=c(0,N+1),y=c(0,T),xlim=c(0,N+1),ylim=c(-.5,T),xlab="", ylab="",type="n",axes=FALSE)

  for(i in 1:N) {
    for(j in 1:T) {
      if(time) text(0,j-1, sprintf("%d", j))
      points(i,T-j, pch=19, cex=1)
    }
  } 

  if(T>1) {
    for(i in 2:T)
      for(j in 1:N)
        lines(c(j, anc[i,j]), c(i-1, i-2))

    # mark MRCA and sample
    mark1<-mark
    MRCA<-0
    if(length(mark1)) {
      for(i in T:2) {
        for(j in mark1) {
          points(j, i-1, pch=19, col=col, cex=cex)
          lines(c(j, anc[i,j]), c(i-1, i-2), col=col, lwd=5*cex)
          if(onevalue(mark1) && MRCA == 0) {
            MRCAx<-j
            MRCAy<-i-1 
            MRCA=1
          }
        }
        mark1<-anc[i, mark1]
      }
      if(markMRCA) points(MRCAx, MRCAy, pch=19, col="blue")
    }
  }
}
  # Untangled version
  if(untangled==TRUE) {
    plot(x=c(0,N+1),y=c(0,T),xlim=c(0,N+1),ylim=c(-.5,T),xlab="", ylab="",type="n",axes=FALSE)

    for(i in 1:N) {
      for(j in 1:T) {
        if(time) text(0,j-1, sprintf("%d", j))
        points(i,T-j, pch=19, cex=1)
      }
    }

    if(T>1) {
      for(i in 2:T)
        for(j in 1:N)
          lines(c(j, anc2[i,j]), c(i-1, i-2))

      # mark MRCA and sample
      MRCA<-0

#      ix<-sort(anc[T,], index.return=TRUE)$ix 

      mark2<-mark
      if(length(mark)) {
        for(i in 1:length(mark)) {
          for(j in 1:N) {
            if(ix[j] == mark[i]) mark2[i]<-j
          }
        }
      }
 
      mark<-mark2

      if(length(mark)) {
        for(i in T:2) {
          for(j in mark) {
            points(j, i-1, pch=19, col=col, cex=cex)
            lines(c(j, anc2[i,j]), c(i-1, i-2), col=col, lwd=5*cex)
            if(onevalue(mark) && MRCA == 0) {
              MRCAx<-j
              MRCAy<-i-1 
              MRCA=1
            }
          }
          mark<-anc2[i, mark]
        }
        if(markMRCA) points(MRCAx, MRCAy, pch=19, col="blue")
      }
    }
  }

  if(pdf) dev.off()
}
