\name{inbreeding}

\alias{inbreeding}

\alias{plot.inbreeding}

\title{Inbreeding}
\description{Show the effect of inbreeding on genetic drift}

\usage{
inbreeding( N=50, f=0.5, stoptime=500, init.A=0.5, batch=1 )

\method{plot}{inbreeding}( x, what=c( "freq.A" ), col=vector(), 
      xlim=NULL, ylim=c( 0, 1 ), xlab="time", ylab="freq", 
      legend.pos="bottomright", ... )
}

\arguments{
   \item{x}{object of class \code{inbreeding}}
   \item{N}{number of individuals}
   \item{f}{inbreeding coefficient}
   \item{stoptime}{stoptime i.e. the number of generations to simulate}
   \item{init.A}{initial frequency of allele A}
   \item{batch}{number of batch runs}
   \item{what}{which curves to show (possible: "freq.A", "freq.a", "fixed" )}
   \item{col}{named vector with colors for each curve defined in \code{what}}
   \item{xlim}{range of x axis; default: 0 to stoptime}
   \item{ylim}{range of y axis; default: 0 to 1}
   \item{xlab}{annotation of x axis}
   \item{ylab}{annotation of y axis}
   \item{legend.pos}{position of legend. See Details}
   \item{\dots}{additional arguments}
}

\details{
\code{inbreeding()} simulates the time evolution of an allele A in a partially selfing population with inbreeding coefficient f. The frequencies of the two possible alleles A and a can be plotted as well as the time to fixation. In the case of batch runs the mean values are plotted.

The location of the legend can be specified by setting 'legend.pos' to a single keyword from the list '"bottomright"', '"bottom"', '"bottomleft"', '"left"', '"topleft"', '"top"', '"topright"', '"right"' and '"center"'. This places the legend on the inside of the plot frame at the given location.
}

\value{
An object of class \code{inbreeding}, a list with elements
\item{freq.A}{a matrix of the allele frequencies of allele A per generation per batch run}
\item{freq.a}{a matrix of the allele frequencies of allele a per generation per batch run}
\item{fixed}{a matrix of logical values indicating whether an allele has come to fixation}
}

\references{\url{http://www.zi.biologie.uni-muenchen.de/~pfaffelhuber/teaching/popgenCourse.html}}
\author{Ulrike Feldmann}

\examples{
ret <- inbreeding( N=100, f=0.2, stoptime=200, init.A=0.3 )

plot( ret )
plot( ret, what=c( "freq.A", "freq.a" ), 
           col=c( "freq.A"="black", "freq.a"="blue" ) )
   
# batch runs
ret <- inbreeding( N=100, f=0.2, stoptime=200, init.A=0.3, batch=500 )

plot( ret, what=c( "freq.A", "fixed" ) )
}

\keyword{distribution}
