\name{linkage}

\alias{linkage}

\alias{plot.linkage}

\title{Linkage Disequilibrium}
\description{Linkage Disequilibrium due to admixture}

\usage{
linkage( freq.A1.pop1=1, freq.B1.pop1=1, 
         freq.A1.pop2=0, freq.B1.pop2=0,
         n.pop1=50, n.pop2=50, rho=0.1, stoptime=100 ) 

\method{plot}{linkage}( x, what=c( "A1B1", "A1B2", "A2B1", "A2B2" ), 
      col=vector(), xlim=NULL, ylim=c( 0, 1 ), xlab="time", 
      ylab="freq", legend.pos="bottomright", ... )
}

\arguments{
   \item{x}{object of class \code{linkage}}
   \item{freq.A1.pop1}{frequency of A1 in population 1}
   \item{freq.B1.pop1}{frequency of B1 in population 1}
   \item{freq.A1.pop2}{frequency of A1 in population 2}
   \item{freq.B1.pop2}{frequency of B1 in population 2}
   \item{n.pop1}{size of population 1}
   \item{n.pop2}{size of population 2}
   \item{rho}{recombination rate between the two loci; should be between 0 and 0.5}
   \item{stoptime}{stoptime i.e. the number of generations to simulate}
   \item{what}{which curves to show (possible: "A1B1", "A1B2", "A2B1", "A2B2", "A1", "A2", "B1", "B2", "LD", "R.squared", "HW.A", "F.A", "HW.B", "F.B" )}
   \item{xlim}{range of x axis; default: 0 to stoptime}
   \item{ylim}{range of y axis; default: 0 to 1}
   \item{xlab}{annotation of x axis}
   \item{ylab}{annotation of y axis}
   \item{col}{named vector with colors for each curve defined in \code{what}}
   \item{legend.pos}{position of legend. See Details}
   \item{\dots}{additional arguments}
}

\details{
\code{linkage()} implements a deterministic two locus two allele model. The scenario is admixture, two populations with different allele frequencies are combined to form one population, and recombination will restore linkage equilibrium after some generations. The popualtions are population 1 and population 2. The loci are A and B, the alleles A1 and A2 and B1 and B2. The frequencies of A1 and B1 in each population can be set by the user, the frequencies of A2 and B2 are then calculated as 1-freq.A1 and 1-freq.B1. 

The location of the legend can be specified by setting 'legend.pos' to a single keyword from the list '"bottomright"', '"bottom"', '"bottomleft"', '"left"', '"topleft"', '"top"', '"topright"', '"right"' and '"center"'. This places the legend on the inside of the plot frame at the given location.
}

\value{
An object of class \code{linkage}, a list with elements
\item{Haplotype.freq}{a dataframe containing the haplotype frequencies for each generation}
\item{Allele.freq}{a dataframe containing the allele frequencies for each generation}
\item{LD}{a vector of linkage disequilibrium per generation}
\item{R.squared}{a vector of \eqn{R^2} per generation}
\item{HW.A}{a vector of Hardy-Weinberg equilibrium at locus A per generation}
\item{F.A}{a vector of the inbreeding coefficient F=(H0-H)/H0 at locus A per generation}
\item{HW.B}{a vector of Hardy-Weinberg equilibrium at locus B per generation}
\item{F.B}{a vector of the inbreeding coefficient F=(H0-H)/H0 at locus B per generation}
}

\references{\url{http://www.zi.biologie.uni-muenchen.de/~pfaffelhuber/teaching/popgenCourse.html}}
\author{Ulrike Feldmann}

\examples{
res <- linkage()

res <- linkage( freq.A1.pop1=0.8, freq.B1.pop1=0, 
                freq.A1.pop2=1, freq.B1.pop2=0.5,
                n.pop1=50, n.pop2=50,
                rho=0.1, stoptime=100 ) 

plot( res, 
      what=c( "A1B1", "A1B2", "A2B1", "A2B2", "A1", "A2", "B1", "B2" ) )
plot( res, what=c( "A1", "A2", "B1", "B2" ) )
plot( res, what=c( "LD", "R.squared" ), 
           col=c( "LD"="blue", "R.squared"="black" ) )
plot( res, what=c( "HW.A", "HW.B", "F.A", "F.B" ) )
}

\keyword{distribution}
